.. -*- mode: ReST -*-

.. _testing:

=======
Testing
=======

.. contents:: Contents


Utilities for testing, such as reusable ``pytest`` fixtures.
Currently consists of :func:`wrap_tmp<jgdv.testing.tempdir.wrap_tmp>`, a fixture to move to a temporary directory for a test.

--------
wrap_tmp
--------


.. code:: python

          # TODO
          
